from distutils.core import setup

setup(
    name ='myselfpyy',
    version ='1.0.1',
    py_modules=['myselfpyy'],
    author='myselff',
    author_email='myselff@qq.com',
    url ='http://myselff.com',
    description='a smaple distution'
  )